@@ -14,13 +14,23 @@ class SamplingPriority(object):
 
 # Datadog trace headers
 class TraceHeader(object):
-    TRACE_ID = 'x-datadog-trace-id'
-    PARENT_ID = 'x-datadog-parent-id'
-    SAMPLING_PRIORITY = 'x-datadog-sampling-priority'
+    TRACE_ID = "x-datadog-trace-id"
+    PARENT_ID = "x-datadog-parent-id"
+    SAMPLING_PRIORITY = "x-datadog-sampling-priority"
 
 
 # X-Ray subsegment to save Datadog trace metadata
 class XraySubsegment(object):
-    NAME = 'datadog-metadata'
-    KEY = 'trace'
-    NAMESPACE = 'datadog'
+    NAME = "datadog-metadata"
+    TRACE_KEY = "trace"
+    LAMBDA_FUNCTION_TAGS_KEY = "lambda_function_tags"
+    NAMESPACE = "datadog"
+
+
+# TraceContextSource of datadog context. The DD_MERGE_XRAY_TRACES
+# feature uses this to determine when to use X-Ray as the parent
+# trace.
+class TraceContextSource(object):
+    XRAY = "xray"
+    EVENT = "event"
+    DDTRACE = "ddtrace"
